package ext.chart.series {

[Native("Ext.chart.series.Bar", require)]
/**
 * Creates a Bar or Column Chart (depending on the value of the
 * →<code>ext.chart.CartesianChart.flipXY</code> config).
 * <p>Note: 'bar' series is meant to be used with the
 * <i>'category'</i> (→<code>ext.chart.axis.AxisCategory</code>) axis as its x-axis.</p>
 * <p><b>Example:</b></p>
 * <pre>
 * Ext.create({
 *    xtype: 'cartesian',
 *    renderTo: document.body,
 *    width: 600,
 *    height: 400,
 *    store: {
 *        fields: ['name', 'value'],
 *        data: [{
 *            name: 'metric one',
 *            value: 10
 *        }, {
 *            name: 'metric two',
 *            value: 7
 *        }, {
 *            name: 'metric three',
 *            value: 5
 *        }, {
 *            name: 'metric four',
 *            value: 2
 *        }, {
 *            name: 'metric five',
 *            value: 27
 *        }]
 *    },
 *    axes: [{
 *        type: 'numeric',
 *        position: 'left',
 *        title: {
 *            text: 'Sample Values',
 *            fontSize: 15
 *        },
 *        fields: 'value'
 *    }, {
 *        type: 'category',
 *        position: 'bottom',
 *        title: {
 *            text: 'Sample Values',
 *            fontSize: 15
 *        },
 *        fields: 'name'
 *    }],
 *    series: {
 *        type: 'bar',
 *        subStyle: {
 *            fill: ['#388FAD'],
 *            stroke: '#1F6D91'
 *        },
 *        xField: 'name',
 *        yField: 'value'
 *    }
 * });
 * </pre>
 * @see ext.chart.CartesianChart#flipXY
 * @see ext.chart.axis.AxisCategory
 * @see https://docs.sencha.com/extjs/6.5.3/classic/Ext.chart.series.Bar.html Original Ext JS documentation of 'Ext.chart.series.Bar'
 */
public class BarSeries extends ext.chart.series.StackedCartesianSeries {
  /**
   * @inheritDoc
   */
  public function BarSeries(config:ext.chart.series.BarSeries = null) {
    super();
  }
}
}